summaryrefslogtreecommitdiff
path: root/gst
diff options
context:
space:
mode:
authorAaron Boxer <aaron.boxer@collabora.com>2019-09-02 15:08:44 -0400
committerAaron Boxer <aaron.boxer@collabora.com>2019-11-05 09:11:25 -0500
commit6d3429af34ed0b5905faf32d2f22b9db2451f116 (patch)
treef18e8fed7a80ddd4db89a76bab109fcd37a76819 /gst
parent2386858a9179aff2ec249bdffa904bf407de455f (diff)
downloadgstreamer-plugins-bad-6d3429af34ed0b5905faf32d2f22b9db2451f116.tar.gz
documentation: fixed a heap o' typos
Diffstat (limited to 'gst')
-rw-r--r--gst/asfmux/gstasfmux.c22
-rw-r--r--gst/asfmux/gstasfobjects.c26
-rw-r--r--gst/audiovisualizers/gstsynaescope.c2
-rw-r--r--gst/autoconvert/gstautoconvert.c2
-rw-r--r--gst/autoconvert/gstautovideoconvert.c4
-rw-r--r--gst/autoconvert/plugin.c2
-rw-r--r--gst/bayer/gstbayer2rgb.c2
-rw-r--r--gst/camerabin2/camerabin2-src.txt2
-rw-r--r--gst/camerabin2/camerabingeneral.c2
-rw-r--r--gst/camerabin2/gstcamerabin2.c2
-rw-r--r--gst/camerabin2/gstviewfinderbin.c2
-rw-r--r--gst/camerabin2/gstwrappercamerabinsrc.c8
-rw-r--r--gst/debugutils/fpsdisplaysink.c2
-rw-r--r--gst/debugutils/gstdebugspy.c2
-rw-r--r--gst/dvbsuboverlay/dvb-sub.c4
-rw-r--r--gst/dvbsuboverlay/dvb-sub.h2
-rw-r--r--gst/dvdspu/Notes.txt4
-rw-r--r--gst/dvdspu/gstspu-vobsub-render.c2
-rw-r--r--gst/festival/gstfestival.c2
-rw-r--r--gst/frei0r/frei0r.h6
-rw-r--r--gst/frei0r/gstfrei0r.c2
-rw-r--r--gst/gaudieffects/gstburn.c2
-rw-r--r--gst/gaudieffects/gstchromium.c2
-rw-r--r--gst/gaudieffects/gstdilate.c2
-rw-r--r--gst/gaudieffects/gstdodge.c2
-rw-r--r--gst/gaudieffects/gstexclusion.c2
-rw-r--r--gst/gaudieffects/gstgaussblur.c2
-rw-r--r--gst/gaudieffects/gstsolarize.c2
-rw-r--r--gst/geometrictransform/gstbulge.c2
-rw-r--r--gst/geometrictransform/gststretch.c2
-rw-r--r--gst/geometrictransform/gsttunnel.c2
-rw-r--r--gst/id3tag/id3tag.c2
-rw-r--r--gst/ivfparse/gstivfparse.c2
-rw-r--r--gst/jpegformat/gstjpegparse.c6
-rw-r--r--gst/librfb/rfbdecoder.c8
-rw-r--r--gst/mpegdemux/gstmpegdemux.c2
-rw-r--r--gst/mpegpsmux/psmux.c2
-rw-r--r--gst/mpegpsmux/psmuxstream.c4
-rw-r--r--gst/mpegpsmux/psmuxstream.h2
-rw-r--r--gst/mpegtsdemux/TODO6
-rw-r--r--gst/mpegtsdemux/mpegtsbase.c2
-rw-r--r--gst/mpegtsdemux/mpegtsbase.h2
-rw-r--r--gst/mpegtsdemux/mpegtspacketizer.c4
-rw-r--r--gst/mpegtsdemux/tsdemux.c2
-rw-r--r--gst/mpegtsmux/gstmpegtsmux.c2
-rw-r--r--gst/mpegtsmux/tsmux/tsmux.c4
-rw-r--r--gst/mpegtsmux/tsmux/tsmuxstream.c2
-rw-r--r--gst/mxf/mxfdms1.c2
-rw-r--r--gst/netsim/gstnetsim.c2
-rw-r--r--gst/pcapparse/gstirtspparse.c2
-rw-r--r--gst/pnm/gstpnmdec.c2
-rw-r--r--gst/removesilence/gstremovesilence.c6
-rw-r--r--gst/rist/gstristrtxsend.c2
-rw-r--r--gst/rist/gstristsink.c2
-rw-r--r--gst/rist/gstroundrobin.c2
-rw-r--r--gst/rtp/gstrtpsrc.c4
-rw-r--r--gst/videoparsers/gsth264parse.c8
-rw-r--r--gst/videoparsers/gsth265parse.c2
-rw-r--r--gst/videoparsers/gstmpeg4videoparse.c2
-rw-r--r--gst/videoparsers/gstmpegvideoparse.c4
-rw-r--r--gst/videoparsers/h263parse.c2
-rw-r--r--gst/vmnc/vmncdec.c4
62 files changed, 110 insertions, 110 deletions
diff --git a/gst/asfmux/gstasfmux.c b/gst/asfmux/gstasfmux.c
index 9896019ff..731600f94 100644
--- a/gst/asfmux/gstasfmux.c
+++ b/gst/asfmux/gstasfmux.c
@@ -458,7 +458,7 @@ content_description_calc_size_for_tag (const GstTagList * taglist,
* and get the same tags in the writing function */
/**
* gst_asf_mux_get_content_description_tags:
- * @asfmux: #GstAsfMux to have its tags proccessed
+ * @asfmux: #GstAsfMux to have its tags processed
* @asftags: #GstAsfTags to hold the results
*
* Inspects the tags received by the GstTagSetter interface
@@ -466,7 +466,7 @@ content_description_calc_size_for_tag (const GstTagList * taglist,
* size needed for the default and extended content description objects.
* This results and a copy of the #GstTagList
* are stored in the #GstAsfTags. We store a copy so that
- * the sizes estimated here mantain the same until they are
+ * the sizes estimated here maintain the same until they are
* written to the asf file.
*/
static void
@@ -784,7 +784,7 @@ gst_asf_mux_write_stream_properties (GstAsfMux * asfmux, guint8 ** buf,
*
* Writes the header of the header extension object. The buffer pointer
* is incremented to the next writing position (the header extension object
- * childs should be writen from that point)
+ * childs should be written from that point)
*/
static void
gst_asf_mux_write_header_extension (GstAsfMux * asfmux, guint8 ** buf,
@@ -802,7 +802,7 @@ gst_asf_mux_write_header_extension (GstAsfMux * asfmux, guint8 ** buf,
* gst_asf_mux_write_extended_stream_properties:
* @asfmux:
* @buf: pointer to the buffer pointer
- * @asfpad: Pad that handles the stream of the properties to be writen
+ * @asfpad: Pad that handles the stream of the properties to be written
*
* Writes the extended stream properties object (that is part of the
* header extension objects) for the stream handled by asfpad
@@ -849,13 +849,13 @@ gst_asf_mux_write_extended_stream_properties (GstAsfMux * asfmux, guint8 ** buf,
* @asfmux:
* @size_buf: pointer to the memory position to write the size of the string
* @str_buf: pointer to the memory position to write the string
- * @str: the string to be writen (in UTF-8)
- * @use32: if the string size should be writen with 32 bits (if true)
+ * @str: the string to be written (in UTF-8)
+ * @use32: if the string size should be written with 32 bits (if true)
* or with 16 (if false)
*
* Writes a string with its size as it is needed in many asf objects.
- * The size is writen to size_buf as a WORD field if use32 is false, and
- * as a DWORD if use32 is true. The string is writen to str_buf in UTF16-LE.
+ * The size is written to size_buf as a WORD field if use32 is false, and
+ * as a DWORD if use32 is true. The string is written to str_buf in UTF16-LE.
* The string should be passed in UTF-8.
*
* The string size in UTF16-LE is returned.
@@ -909,8 +909,8 @@ gst_asf_mux_write_string_with_size (GstAsfMux * asfmux,
* @data_buf:
*
* Checks if a string tag with tagname exists in the taglist. If it
- * exists it is writen as an UTF-16LE to data_buf and its size in bytes
- * is writen to size_buf. It is used for writing content description
+ * exists it is written as an UTF-16LE to data_buf and its size in bytes
+ * is written to size_buf. It is used for writing content description
* object fields.
*
* Returns: the size of the string
@@ -1404,7 +1404,7 @@ gst_asf_mux_start_file (GstAsfMux * asfmux)
* @videopad:
*
* Adds a new entry to the simple index of the stream handler by videopad.
- * This functions doesn't check if the time ellapsed
+ * This functions doesn't check if the time elapsed
* is larger than the established time interval between entries. The caller
* is responsible for verifying this.
*/
diff --git a/gst/asfmux/gstasfobjects.c b/gst/asfmux/gstasfobjects.c
index f8455d970..78e5038b8 100644
--- a/gst/asfmux/gstasfobjects.c
+++ b/gst/asfmux/gstasfobjects.c
@@ -220,7 +220,7 @@ gst_asf_payload_get_size (AsfPayload * payload)
* gst_asf_payload_free:
* @payload: the #AsfPayload to be freed
*
- * Releases teh memory associated with this payload
+ * Releases the memory associated with this payload
*/
void
gst_asf_payload_free (AsfPayload * payload)
@@ -278,7 +278,7 @@ gst_asf_match_guid (const guint8 * data, const Guid * guid)
/**
* gst_asf_put_i32:
* @buf: the memory to write data to
- * @data: the value to be writen
+ * @data: the value to be written
*
* Writes a 32 bit signed integer to memory
*/
@@ -291,7 +291,7 @@ gst_asf_put_i32 (guint8 * buf, gint32 data)
/**
* gst_asf_put_time:
* @buf: pointer to the buffer to write the value to
- * @time: value to be writen
+ * @time: value to be written
*
* Writes an asf time value to the buffer
*/
@@ -304,7 +304,7 @@ gst_asf_put_time (guint8 * buf, guint64 time)
/**
* gst_asf_put_guid:
* @buf: the buffer to write the guid to
- * @guid: the guid to be writen
+ * @guid: the guid to be written
*
* Writes a GUID to the buffer
*/
@@ -324,7 +324,7 @@ gst_asf_put_guid (guint8 * buf, Guid guid)
/**
* gst_asf_put_payload:
* @buf: memory to write the payload to
- * @payload: #AsfPayload to be writen
+ * @payload: #AsfPayload to be written
*
* Writes the asf payload to the buffer. The #AsfPayload
* packet count is incremented.
@@ -348,19 +348,19 @@ gst_asf_put_payload (guint8 * buf, AsfPayload * payload)
/**
* gst_asf_put_subpayload:
* @buf: buffer to write the payload to
- * @payload: the payload to be writen
+ * @payload: the payload to be written
* @size: maximum size in bytes to write
*
* Serializes part of a payload to a buffer.
* The maximum size is checked against the payload length,
- * the minimum of this size and the payload length is writen
- * to the buffer and the writen size is returned.
+ * the minimum of this size and the payload length is written
+ * to the buffer and the written size is returned.
*
* It also updates the values of the payload to match the remaining
* data.
* In case there is not enough space to write the headers, nothing is done.
*
- * Returns: The writen size in bytes.
+ * Returns: The written size in bytes.
*/
guint16
gst_asf_put_subpayload (guint8 * buf, AsfPayload * payload, guint16 size)
@@ -461,7 +461,7 @@ gst_asf_match_and_peek_obj_size_buf (GstBuffer * buf, const Guid * guid)
* is the last one in an asf packet and the remaining data
* is probably uninteresting to the application.
*
- * Returns: true on success, false if some error occurrs
+ * Returns: true on success, false if some error occurs
*/
static gboolean
gst_asf_parse_mult_payload (GstByteReader * reader, gboolean * has_keyframe)
@@ -486,7 +486,7 @@ gst_asf_parse_mult_payload (GstByteReader * reader, gboolean * has_keyframe)
if (!gst_byte_reader_get_uint8 (reader, &stream_num))
goto error;
if ((stream_num & 0x80) != 0) {
- GST_LOG ("Keyframe found, stoping parse of payloads");
+ GST_LOG ("Keyframe found, stopping parse of payloads");
*has_keyframe = TRUE;
return TRUE;
}
@@ -525,7 +525,7 @@ error:
* is the last one in an asf packet and the remaining data
* is probably uninteresting to the application.
*
- * Returns: true on success, false if some error occurrs
+ * Returns: true on success, false if some error occurs
*/
static gboolean
gst_asf_parse_single_payload (GstByteReader * reader, gboolean * has_keyframe)
@@ -753,7 +753,7 @@ gst_asf_parse_file_properties_obj (GstByteReader * reader,
return GST_FLOW_ERROR;
if (min_ps != max_ps) {
- GST_WARNING ("Mininum and maximum packet size differ "
+ GST_WARNING ("Minimum and maximum packet size differ "
"%" G_GUINT32_FORMAT " and %" G_GUINT32_FORMAT ", "
"ASF spec states they should be the same", min_ps, max_ps);
return FALSE;
diff --git a/gst/audiovisualizers/gstsynaescope.c b/gst/audiovisualizers/gstsynaescope.c
index 4b5c0ed5a..1e2be0599 100644
--- a/gst/audiovisualizers/gstsynaescope.c
+++ b/gst/audiovisualizers/gstsynaescope.c
@@ -268,7 +268,7 @@ gst_synae_scope_render (GstAudioVisualizer * bscope, GstBuffer * audio,
fc = r + l;
x = (guint) (r * w / fc);
- /* the brighness scaling factor was picked by experimenting */
+ /* the brightness scaling factor was picked by experimenting */
br = b * fc * 0.01;
br1 = br * (clarity + 128) >> 8;
diff --git a/gst/autoconvert/gstautoconvert.c b/gst/autoconvert/gstautoconvert.c
index de2bbf8cb..46bec1314 100644
--- a/gst/autoconvert/gstautoconvert.c
+++ b/gst/autoconvert/gstautoconvert.c
@@ -164,7 +164,7 @@ gst_auto_convert_class_init (GstAutoConvertClass * klass)
gst_element_class_add_static_pad_template (gstelement_class, &sinktemplate);
gst_element_class_set_static_metadata (gstelement_class,
- "Select convertor based on caps", "Generic/Bin",
+ "Select converter based on caps", "Generic/Bin",
"Selects the right transform element based on the caps",
"Olivier Crete <olivier.crete@collabora.com>");
diff --git a/gst/autoconvert/gstautovideoconvert.c b/gst/autoconvert/gstautovideoconvert.c
index 7e0ea9eae..2e6fe030a 100644
--- a/gst/autoconvert/gstautovideoconvert.c
+++ b/gst/autoconvert/gstautovideoconvert.c
@@ -144,8 +144,8 @@ gst_auto_video_convert_class_init (GstAutoVideoConvertClass * klass)
gst_element_class_add_static_pad_template (gstelement_class, &sinktemplate);
gst_element_class_set_static_metadata (gstelement_class,
- "Select color space convertor based on caps", "Generic/Bin",
- "Selects the right color space convertor based on the caps",
+ "Select color space converter based on caps", "Generic/Bin",
+ "Selects the right color space converter based on the caps",
"Benjamin Gaignard <benjamin.gaignard@stericsson.com>");
gstelement_class->change_state =
diff --git a/gst/autoconvert/plugin.c b/gst/autoconvert/plugin.c
index 0c7cb6a16..03c05ab37 100644
--- a/gst/autoconvert/plugin.c
+++ b/gst/autoconvert/plugin.c
@@ -42,5 +42,5 @@ plugin_init (GstPlugin * plugin)
GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
GST_VERSION_MINOR,
autoconvert,
- "Selects convertor element based on caps",
+ "Selects converter element based on caps",
plugin_init, VERSION, GST_LICENSE, GST_PACKAGE_NAME, GST_PACKAGE_ORIGIN)
diff --git a/gst/bayer/gstbayer2rgb.c b/gst/bayer/gstbayer2rgb.c
index a6d24eab1..e13a5cc0a 100644
--- a/gst/bayer/gstbayer2rgb.c
+++ b/gst/bayer/gstbayer2rgb.c
@@ -64,7 +64,7 @@
* "nearest neighbor" principal, with some additional complexity for the
* calculation of the "green" element, where an "adaptive" pairing is used.
*
- * For purposes of documentation and indentification, each element of the
+ * For purposes of documentation and identification, each element of the
* original array can be put into one of four classes:
* R A red element
* B A blue element
diff --git a/gst/camerabin2/camerabin2-src.txt b/gst/camerabin2/camerabin2-src.txt
index f50288e67..716d959b7 100644
--- a/gst/camerabin2/camerabin2-src.txt
+++ b/gst/camerabin2/camerabin2-src.txt
@@ -48,7 +48,7 @@ recommended that the viewfinder pad keeps pushing buffers so the user
has a smooth experience.
Note that basecamerasrc already has the mode property and start/stop-capture
-signals. It has functions that should be overriden by its child classes to
+signals. It has functions that should be overridden by its child classes to
implement the handling of these actions.
diff --git a/gst/camerabin2/camerabingeneral.c b/gst/camerabin2/camerabingeneral.c
index 799c86d3a..9a60d35ed 100644
--- a/gst/camerabin2/camerabingeneral.c
+++ b/gst/camerabin2/camerabingeneral.c
@@ -175,7 +175,7 @@ gst_camerabin_create_and_add_element (GstBin * bin, const gchar * elem_name,
/* try to change the state of an element. This function returns the element
* when the state change could be performed. When this function returns NULL
- * an error occured and the element is unreffed. */
+ * an error occurred and the element is unreffed. */
static GstElement *
try_element (GstElement * bin, GstElement * element)
{
diff --git a/gst/camerabin2/gstcamerabin2.c b/gst/camerabin2/gstcamerabin2.c
index 681066d18..83210f4bb 100644
--- a/gst/camerabin2/gstcamerabin2.c
+++ b/gst/camerabin2/gstcamerabin2.c
@@ -782,7 +782,7 @@ gst_camera_bin_class_init (GstCameraBin2Class * klass)
* show that jifmux is picked if image/jpeg is the caps of a container
* profile. So this could work.
* - There seems to be a problem with encodebin for images currently as
- * it autoplugs a videorate that only starts outputing buffers after
+ * it autoplugs a videorate that only starts outputting buffers after
* getting the 2nd buffer.
*/
g_object_class_install_property (object_class, PROP_IMAGE_ENCODING_PROFILE,
diff --git a/gst/camerabin2/gstviewfinderbin.c b/gst/camerabin2/gstviewfinderbin.c
index 78f172527..4ff7335a4 100644
--- a/gst/camerabin2/gstviewfinderbin.c
+++ b/gst/camerabin2/gstviewfinderbin.c
@@ -216,7 +216,7 @@ gst_viewfinder_bin_create_elements (GstViewfinderBin * vfbin)
GST_PAD_LINK_CHECK_NOTHING);
vfbin->elements_created = TRUE;
- GST_DEBUG_OBJECT (vfbin, "Elements succesfully created and linked");
+ GST_DEBUG_OBJECT (vfbin, "Elements successfully created and linked");
updated_converters = TRUE;
}
diff --git a/gst/camerabin2/gstwrappercamerabinsrc.c b/gst/camerabin2/gstwrappercamerabinsrc.c
index c1c6dc5ee..6fd11292a 100644
--- a/gst/camerabin2/gstwrappercamerabinsrc.c
+++ b/gst/camerabin2/gstwrappercamerabinsrc.c
@@ -200,7 +200,7 @@ gst_wrapper_camera_bin_reset_video_src_caps (GstWrapperCameraBinSrc * self,
/* After pipe was negotiated src_filter do not have any filter caps.
* In this situation we should compare negotiated caps on capsfilter pad
* with requested range of caps. If one of this caps intersect,
- * then we can avoid reseting.
+ * then we can avoid resetting.
*/
src_neg_caps = gst_pad_get_current_caps (self->srcfilter_pad);
if (src_neg_caps && new_filter_caps && gst_caps_is_fixed (new_filter_caps))
@@ -209,7 +209,7 @@ gst_wrapper_camera_bin_reset_video_src_caps (GstWrapperCameraBinSrc * self,
/* If new_filter_caps = NULL, then some body wont to empty
* capsfilter (set to ANY). In this case we will need to reset pipe,
* but if capsfilter is actually empthy, then we can avoid
- * one more reseting.
+ * one more resetting.
*/
GstCaps *old_filter_caps; /* range of caps on capsfilter */
@@ -592,7 +592,7 @@ gst_wrapper_camera_bin_src_construct_pipeline (GstBaseCameraSrc * bcamsrc)
/* keep a 'tee' element that has 2 source pads, one is linked to the
* vidsrc pad and the other is linked as needed to the viewfinder
- * when video recording is hapenning */
+ * when video recording is happening */
video_recording_tee = gst_element_factory_make ("tee", "video_rec_tee");
gst_bin_add (GST_BIN_CAST (self), video_recording_tee); /* TODO check returns */
self->video_tee_vf_pad =
@@ -1039,7 +1039,7 @@ gst_wrapper_camera_bin_src_stop_capture (GstBaseCameraSrc * camerasrc)
{
GstWrapperCameraBinSrc *src = GST_WRAPPER_CAMERA_BIN_SRC (camerasrc);
- /* TODO shoud we access this directly? Maybe a macro is better? */
+ /* TODO should we access this directly? Maybe a macro is better? */
if (src->mode == MODE_VIDEO) {
if (src->video_rec_status == GST_VIDEO_RECORDING_STATUS_STARTING) {
GST_DEBUG_OBJECT (src, "Aborting, had not started recording");
diff --git a/gst/debugutils/fpsdisplaysink.c b/gst/debugutils/fpsdisplaysink.c
index 9774b6a52..90c429e9c 100644
--- a/gst/debugutils/fpsdisplaysink.c
+++ b/gst/debugutils/fpsdisplaysink.c
@@ -179,7 +179,7 @@ fps_display_sink_class_init (GstFPSDisplaySinkClass * klass)
g_object_class_install_property (gobject_klass, PROP_SIGNAL_FPS_MEASUREMENTS,
g_param_spec_boolean ("signal-fps-measurements",
"Signal fps measurements",
- "If the fps-measurements signal should be emited.",
+ "If the fps-measurements signal should be emitted.",
DEFAULT_SIGNAL_FPS_MEASUREMENTS,
G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE));
diff --git a/gst/debugutils/gstdebugspy.c b/gst/debugutils/gstdebugspy.c
index ebf050f6d..baacc4bc8 100644
--- a/gst/debugutils/gstdebugspy.c
+++ b/gst/debugutils/gstdebugspy.c
@@ -147,7 +147,7 @@ gst_debug_spy_class_init (GstDebugSpyClass * klass)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
diff --git a/gst/dvbsuboverlay/dvb-sub.c b/gst/dvbsuboverlay/dvb-sub.c
index 2e6e48dde..3c056326e 100644
--- a/gst/dvbsuboverlay/dvb-sub.c
+++ b/gst/dvbsuboverlay/dvb-sub.c
@@ -82,7 +82,7 @@ typedef struct DVBSubObjectDisplay
int fgcolor;
int bgcolor;
- /* FIXME: Should we use GSList? The relating interaction and pointer assigment is quite complex and perhaps unsuited for a plain GSList anyway */
+ /* FIXME: Should we use GSList? The relating interaction and pointer assignment is quite complex and perhaps unsuited for a plain GSList anyway */
struct DVBSubObjectDisplay *region_list_next;
struct DVBSubObjectDisplay *object_list_next;
} DVBSubObjectDisplay;
@@ -1360,7 +1360,7 @@ dvb_sub_free (DvbSub * sub)
* the PTS information).
*
* Return value: -1 if data was unhandled (e.g, not a subtitle packet),
- * -2 if data parsing was unsuccesful (e.g, length was invalid),
+ * -2 if data parsing was unsuccessful (e.g, length was invalid),
* 0 or positive if data was handled. If positive, then amount of data consumed on success. FIXME: List the positive return values.
*/
gint
diff --git a/gst/dvbsuboverlay/dvb-sub.h b/gst/dvbsuboverlay/dvb-sub.h
index 5917e7e49..c986422a6 100644
--- a/gst/dvbsuboverlay/dvb-sub.h
+++ b/gst/dvbsuboverlay/dvb-sub.h
@@ -33,7 +33,7 @@ typedef struct _DvbSub DvbSub;
* as an index into the @palette.
* @palette: the palette used for this subtitle rectangle, up to 256 items depending
* on the depth of the subpicture; each palette item is in ARGB form, 8-bits per channel.
- * @palette_bits_count: the amount of bits used in indeces into @palette in @data.
+ * @palette_bits_count: the amount of bits used in indices into @palette in @data.
* @rowstride: the number of bytes between the start of a row and the start of the next row.
*
* A structure representing the contents of a subtitle rectangle.
diff --git a/gst/dvdspu/Notes.txt b/gst/dvdspu/Notes.txt
index a0e56e3c1..12f0af673 100644
--- a/gst/dvdspu/Notes.txt
+++ b/gst/dvdspu/Notes.txt
@@ -126,11 +126,11 @@ as I know, each type has a fixed length.
* type 0x03 : '03wxyz' - 3 bytes
this one has the palette information ; it basically says 'encoded color 0
- is the wth color of the palette, encoded color 1 is the xth color, aso.
+ is the with color of the palette, encoded color 1 is the xth color, aso.
* type 0x04 : '04wxyz' - 3 bytes
I *think* this is the alpha channel information ; I only saw values of 0 or f
- for those nibbles, so I can't really be sure, but it seems plausable.
+ for those nibbles, so I can't really be sure, but it seems plausible.
* type 0x05 : '05xxxXXXyyyYYY' - 7 bytes
the coordinates of the subtitle on the screen :
diff --git a/gst/dvdspu/gstspu-vobsub-render.c b/gst/dvdspu/gstspu-vobsub-render.c
index f4649e9e9..df4e54b9c 100644
--- a/gst/dvdspu/gstspu-vobsub-render.c
+++ b/gst/dvdspu/gstspu-vobsub-render.c
@@ -317,7 +317,7 @@ gstspu_vobsub_render_line_with_chgcol (SpuState * state, guint8 * planes[3],
disp_end = state->vobsub.disp_rect.right + 1;
/* Work out the first pixel control info, which may point to the dummy entry if
- * the global palette/alpha need using initally */
+ * the global palette/alpha need using initially */
cur_pix_ctrl = chg_col->pix_ctrl_i;
end_pix_ctrl = chg_col->pix_ctrl_i + chg_col->n_changes;
diff --git a/gst/festival/gstfestival.c b/gst/festival/gstfestival.c
index fbe9ecdae..d1637ab46 100644
--- a/gst/festival/gstfestival.c
+++ b/gst/festival/gstfestival.c
@@ -396,7 +396,7 @@ socket_receive_file_to_buff (int fd, int *size)
{
/* Receive file (probably a waveform file) from socket using */
/* Festival key stuff technique, but long winded I know, sorry */
- /* but will receive any file without closeing the stream or */
+ /* but will receive any file without closing the stream or */
/* using OOB data */
static const char file_stuff_key[] = "ft_StUfF_key"; /* must == Festival's key */
char *buff;
diff --git a/gst/frei0r/frei0r.h b/gst/frei0r/frei0r.h
index 9aed4453b..88a05a316 100644
--- a/gst/frei0r/frei0r.h
+++ b/gst/frei0r/frei0r.h
@@ -128,7 +128,7 @@
* @subsection sec_icon_location Icon location
*
* The exact location where the application should look for the
- * plugin is platform dependant.
+ * plugin is platform dependent.
*
* For Windows platforms, the icon should be at the same place as
* the plugin containing the effect.
@@ -251,7 +251,7 @@ void f0r_deinit();
* List of supported color models.
*
* Note: the color models are endian independent, because the
- * color components are defined by their positon in memory, not
+ * color components are defined by their position in memory, not
* by their significance in an uint32_t value.
*
* For effects that work on the color components,
@@ -300,7 +300,7 @@ void f0r_deinit();
/**
* In PACKED32, each pixel is represented by 4 consecutive
- * bytes, but it is not defined how the color componets are
+ * bytes, but it is not defined how the color components are
* stored. The true color format could be RGBA8888,
* BGRA8888, a packed 32 bit YUV format, or any other
* color format that stores pixels in 32 bit.
diff --git a/gst/frei0r/gstfrei0r.c b/gst/frei0r/gstfrei0r.c
index b887f6398..6a00934e8 100644
--- a/gst/frei0r/gstfrei0r.c
+++ b/gst/frei0r/gstfrei0r.c
@@ -550,7 +550,7 @@ register_plugin (GstPlugin * plugin, const gchar * vendor,
instance = ftable.construct (640, 480);
if (!instance) {
- GST_WARNING ("Failed to instanciate plugin '%s'", info.name);
+ GST_WARNING ("Failed to instantiate plugin '%s'", info.name);
ftable.deinit ();
g_module_close (module);
return FALSE;
diff --git a/gst/gaudieffects/gstburn.c b/gst/gaudieffects/gstburn.c
index bf662270a..bc5aefb63 100644
--- a/gst/gaudieffects/gstburn.c
+++ b/gst/gaudieffects/gstburn.c
@@ -157,7 +157,7 @@ gst_burn_class_init (GstBurnClass * klass)
/* Initialize the element,
* instantiate pads and add them to element,
- * set pad calback functions, and
+ * set pad callback functions, and
* initialize instance structure.
*/
static void
diff --git a/gst/gaudieffects/gstchromium.c b/gst/gaudieffects/gstchromium.c
index fb55aac25..1a3f3666e 100644
--- a/gst/gaudieffects/gstchromium.c
+++ b/gst/gaudieffects/gstchromium.c
@@ -177,7 +177,7 @@ gst_chromium_class_init (GstChromiumClass * klass)
/* Initialize the element,
* instantiate pads and add them to element,
- * set pad calback functions, and
+ * set pad callback functions, and
* initialize instance structure.
*/
static void
diff --git a/gst/gaudieffects/gstdilate.c b/gst/gaudieffects/gstdilate.c
index a21ab3d5a..2a1e77521 100644
--- a/gst/gaudieffects/gstdilate.c
+++ b/gst/gaudieffects/gstdilate.c
@@ -159,7 +159,7 @@ gst_dilate_class_init (GstDilateClass * klass)
/* Initialize the element,
* instantiate pads and add them to element,
- * set pad calback functions, and
+ * set pad callback functions, and
* initialize instance structure.
*/
static void
diff --git a/gst/gaudieffects/gstdodge.c b/gst/gaudieffects/gstdodge.c
index 86b5d9d02..ee2ce7dbf 100644
--- a/gst/gaudieffects/gstdodge.c
+++ b/gst/gaudieffects/gstdodge.c
@@ -150,7 +150,7 @@ gst_dodge_class_init (GstDodgeClass * klass)
/* Initialize the element,
* instantiate pads and add them to element,
- * set pad calback functions, and
+ * set pad callback functions, and
* initialize instance structure.
*/
static void
diff --git a/gst/gaudieffects/gstexclusion.c b/gst/gaudieffects/gstexclusion.c
index 62445bd06..6c696b6f3 100644
--- a/gst/gaudieffects/gstexclusion.c
+++ b/gst/gaudieffects/gstexclusion.c
@@ -160,7 +160,7 @@ gst_exclusion_class_init (GstExclusionClass * klass)
/* Initialize the element,
* instantiate pads and add them to element,
- * set pad calback functions, and
+ * set pad callback functions, and
* initialize instance structure.
*/
static void
diff --git a/gst/gaudieffects/gstgaussblur.c b/gst/gaudieffects/gstgaussblur.c
index ff5ca520e..dc2d479f9 100644
--- a/gst/gaudieffects/gstgaussblur.c
+++ b/gst/gaudieffects/gstgaussblur.c
@@ -123,7 +123,7 @@ G_DEFINE_TYPE (GstGaussianBlur, gst_gaussianblur, GST_TYPE_VIDEO_FILTER);
#define DEFAULT_SIGMA 1.2
-/* Initalize the gaussianblur's class. */
+/* Initialize the gaussianblur's class. */
static void
gst_gaussianblur_class_init (GstGaussianBlurClass * klass)
{
diff --git a/gst/gaudieffects/gstsolarize.c b/gst/gaudieffects/gstsolarize.c
index 8fc9ff69e..23a69d0d8 100644
--- a/gst/gaudieffects/gstsolarize.c
+++ b/gst/gaudieffects/gstsolarize.c
@@ -173,7 +173,7 @@ gst_solarize_class_init (GstSolarizeClass * klass)
/* Initialize the element,
* instantiate pads and add them to element,
- * set pad calback functions, and
+ * set pad callback functions, and
* initialize instance structure.
*/
static void
diff --git a/gst/geometrictransform/gstbulge.c b/gst/geometrictransform/gstbulge.c
index 01e850b12..315aa0cd2 100644
--- a/gst/geometrictransform/gstbulge.c
+++ b/gst/geometrictransform/gstbulge.c
@@ -139,7 +139,7 @@ bulge_map (GstGeometricTransform * gt, gint x, gint y, gdouble * in_x,
gdouble width = gt->width;
gdouble height = gt->height;
- /* normalize in ((-1.0, -1.0), (1.0, 1.0) and traslate the center */
+ /* normalize in ((-1.0, -1.0), (1.0, 1.0) and translate the center */
norm_x = 2.0 * (x / width - cgt->x_center);
norm_y = 2.0 * (y / height - cgt->y_center);
diff --git a/gst/geometrictransform/gststretch.c b/gst/geometrictransform/gststretch.c
index 114a0cd22..77086f07d 100644
--- a/gst/geometrictransform/gststretch.c
+++ b/gst/geometrictransform/gststretch.c
@@ -139,7 +139,7 @@ stretch_map (GstGeometricTransform * gt, gint x, gint y, gdouble * in_x,
gdouble height = gt->height;
gdouble a, b;
- /* normalize in ((-1.0, -1.0), (1.0, 1.0) and traslate the center */
+ /* normalize in ((-1.0, -1.0), (1.0, 1.0) and translate the center */
norm_x = 2.0 * (x / width - cgt->x_center);
norm_y = 2.0 * (y / height - cgt->y_center);
diff --git a/gst/geometrictransform/gsttunnel.c b/gst/geometrictransform/gsttunnel.c
index 8668a5282..2dd9c41e3 100644
--- a/gst/geometrictransform/gsttunnel.c
+++ b/gst/geometrictransform/gsttunnel.c
@@ -87,7 +87,7 @@ tunnel_map (GstGeometricTransform * gt, gint x, gint y, gdouble * in_x,
gdouble r;
- /* normalize in ((-1.0, -1.0), (1.0, 1.0) and traslate the center */
+ /* normalize in ((-1.0, -1.0), (1.0, 1.0) and translate the center */
/* plus a little trick to obtain a perfect circle, normalize in a
* square with sides equal to MAX(width, height) */
norm_x = 2.0 * (x - cgt->x_center * width) / MAX (width, height);
diff --git a/gst/id3tag/id3tag.c b/gst/id3tag/id3tag.c
index db4489251..8ba327dee 100644
--- a/gst/id3tag/id3tag.c
+++ b/gst/id3tag/id3tag.c
@@ -1212,7 +1212,7 @@ foreach_add_tag (const GstTagList * list, const gchar * tag, gpointer userdata)
GST_LOG ("Processing tag %s (num=%u)", tag, num_tags);
if (num_tags > 1 && gst_tag_is_fixed (tag)) {
- GST_WARNING ("Multiple occurences of fixed tag '%s', ignoring some", tag);
+ GST_WARNING ("Multiple occurrences of fixed tag '%s', ignoring some", tag);
num_tags = 1;
}
diff --git a/gst/ivfparse/gstivfparse.c b/gst/ivfparse/gstivfparse.c
index 14dd0dda7..34675de77 100644
--- a/gst/ivfparse/gstivfparse.c
+++ b/gst/ivfparse/gstivfparse.c
@@ -123,7 +123,7 @@ gst_ivf_parse_reset (GstIvfParse * ivf)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
diff --git a/gst/jpegformat/gstjpegparse.c b/gst/jpegformat/gstjpegparse.c
index 17cbec954..244b5a2f3 100644
--- a/gst/jpegformat/gstjpegparse.c
+++ b/gst/jpegformat/gstjpegparse.c
@@ -428,15 +428,15 @@ gst_jpeg_parse_skip_marker (GstJpegParse * parse,
const gchar *id_str = NULL;
if (gst_byte_reader_peek_string_utf8 (reader, &id_str)) {
- GST_DEBUG_OBJECT (parse, "unhandled marker %x: '%s' skiping %u bytes",
+ GST_DEBUG_OBJECT (parse, "unhandled marker %x: '%s' skipping %u bytes",
marker, id_str ? id_str : "(NULL)", size);
} else {
- GST_DEBUG_OBJECT (parse, "unhandled marker %x skiping %u bytes", marker,
+ GST_DEBUG_OBJECT (parse, "unhandled marker %x skipping %u bytes", marker,
size);
}
}
#else
- GST_DEBUG_OBJECT (parse, "unhandled marker %x skiping %u bytes", marker,
+ GST_DEBUG_OBJECT (parse, "unhandled marker %x skipping %u bytes", marker,
size);
#endif // GST_DISABLE_GST_DEBUG
diff --git a/gst/mpegdemux/gstmpegdemux.c b/gst/mpegdemux/gstmpegdemux.c
index b229da930..42bb15b8c 100644
--- a/gst/mpegdemux/gstmpegdemux.c
+++ b/gst/mpegdemux/gstmpegdemux.c
@@ -2989,7 +2989,7 @@ pause:
}
}
-/* If we can pull that's prefered */
+/* If we can pull that's preferred */
static gboolean
gst_ps_demux_sink_activate (GstPad * sinkpad, GstObject * parent)
{
diff --git a/gst/mpegpsmux/psmux.c b/gst/mpegpsmux/psmux.c
index a8ba47867..a59f485d6 100644
--- a/gst/mpegpsmux/psmux.c
+++ b/gst/mpegpsmux/psmux.c
@@ -248,7 +248,7 @@ psmux_write_stream_packet (PsMux * mux, PsMuxStream * stream)
/* Time to write pack header */
/* FIXME: currently we write the mux rate of the PREVIOUS pack into the
* pack header, because of the incapability to calculate the mux_rate
- * before outputing the pack. To calculate the mux_rate for the current
+ * before outputting the pack. To calculate the mux_rate for the current
* pack, we need to put the whole pack into buffer, calculate the
* mux_rate, and then output the whole trunck.
*/
diff --git a/gst/mpegpsmux/psmuxstream.c b/gst/mpegpsmux/psmuxstream.c
index 22026a1e5..dc5b4fd52 100644
--- a/gst/mpegpsmux/psmuxstream.c
+++ b/gst/mpegpsmux/psmuxstream.c
@@ -283,7 +283,7 @@ psmux_stream_get_data (PsMuxStream * stream, guint8 * buf, guint len)
MIN (psmux_stream_bytes_in_buffer (stream), len - PSMUX_PES_MAX_HDR_LEN);
/* Note that we cannot make a better estimation of the header length for the
* time being; because the header length is dependent on whether we can find a
- * timestamp in the upcomming buffers, which in turn depends on
+ * timestamp in the upcoming buffers, which in turn depends on
* cur_pes_payload_size, which is exactly what we want to decide.
*/
@@ -463,7 +463,7 @@ psmux_stream_write_pes_header (PsMuxStream * stream, guint8 * data)
if (stream->pi.flags & PSMUX_PACKET_FLAG_PES_EXT_STREAMID) {
guint8 ext_len;
- flags = 0x0f; /* preceeding flags all 0 | (reserved bits) | PES_extension_flag_2 */
+ flags = 0x0f; /* preceding flags all 0 | (reserved bits) | PES_extension_flag_2 */
*data++ = flags;
ext_len = 1; /* Only writing 1 byte into the extended fields */
diff --git a/gst/mpegpsmux/psmuxstream.h b/gst/mpegpsmux/psmuxstream.h
index 0b3c139cd..22f6d7340 100644
--- a/gst/mpegpsmux/psmuxstream.h
+++ b/gst/mpegpsmux/psmuxstream.h
@@ -157,7 +157,7 @@ void psmux_stream_get_es_descrs (PsMuxStream *stream, guint8 *buf, guint16 *l
/* get the pts of stream */
guint64 psmux_stream_get_pts (PsMuxStream *stream);
-/* stream_id assignemnt */
+/* stream_id assignment */
#define PSMUX_STREAM_ID_MPGA_INIT 0xc0
#define PSMUX_STREAM_ID_MPGA_MAX 0xcf
diff --git a/gst/mpegtsdemux/TODO b/gst/mpegtsdemux/TODO
index d4d2563a7..62449ef56 100644
--- a/gst/mpegtsdemux/TODO
+++ b/gst/mpegtsdemux/TODO
@@ -1,7 +1,7 @@
tsdemux/tsparse TODO
--------------------
-* Perfomance
+* Performance
* Bufferlist : Creating/Destroying very small buffers is too
costly. Switch to pre-/re-allocating outgoing buffers in which we
copy the data.
@@ -18,7 +18,7 @@ tsdemux/tsparse TODO
* mpegtsparser
* SERIOUS room for improvement performance-wise (see callgrind),
- mostly related to performance issues mentionned above.
+ mostly related to performance issues mentioned above.
* Random-access seeking
* Do minimal parsing of video headers to detect keyframes and use
@@ -92,7 +92,7 @@ of the stream.
Since no prerolling is happening downstream and the incoming buffers
do not have capture timestamps, we need to ensure the first buffer
- we push out corresponds to the base segment start runing time.
+ we push out corresponds to the base segment start running time.
=> The packetizer keeps track of PCR locations and offsets in
addition to the clock skew (in the case of upstream buffers
diff --git a/gst/mpegtsdemux/mpegtsbase.c b/gst/mpegtsdemux/mpegtsbase.c
index d49ab5eb9..d2d973ad5 100644
--- a/gst/mpegtsdemux/mpegtsbase.c
+++ b/gst/mpegtsdemux/mpegtsbase.c
@@ -1116,7 +1116,7 @@ mpegts_base_apply_pmt (MpegTSBase * base, GstMpegtsSection * section)
program = mpegts_base_new_program (base, program_number, section->pid);
program->patcount = old_program->patcount;
- /* Desactivate the old program */
+ /* Deactivate the old program */
/* FIXME : THIS IS BREAKING THE STREAM SWITCHING LOGIC !
* */
if (klass->can_remove_program (base, old_program)) {
diff --git a/gst/mpegtsdemux/mpegtsbase.h b/gst/mpegtsdemux/mpegtsbase.h
index 79705a77b..30a41ba86 100644
--- a/gst/mpegtsdemux/mpegtsbase.h
+++ b/gst/mpegtsdemux/mpegtsbase.h
@@ -201,7 +201,7 @@ struct _MpegTSBaseClass {
GstFlowReturn (*drain) (MpegTSBase * base);
/* flush all streams
- * The hard inicator is used to flush completelly on FLUSH_STOP events
+ * The hard inicator is used to flush completely on FLUSH_STOP events
* or partially in pull mode seeks of tsdemux */
void (*flush) (MpegTSBase * base, gboolean hard);
diff --git a/gst/mpegtsdemux/mpegtspacketizer.c b/gst/mpegtsdemux/mpegtspacketizer.c
index b16c9b094..b793f8545 100644
--- a/gst/mpegtsdemux/mpegtspacketizer.c
+++ b/gst/mpegtsdemux/mpegtspacketizer.c
@@ -1280,7 +1280,7 @@ mpegts_packetizer_resync (MpegTSPCR * pcr, GstClockTime time,
* Cri : The time of the clock at the receiver for packet i
* D + ni : The jitter when receiving packet i
*
- * We see that the network delay is irrelevant here as we can elliminate D:
+ * We see that the network delay is irrelevant here as we can eliminate D:
*
* recv_diff(i) = (Cri + ni) - (Cr0 + n0))
*
@@ -1613,7 +1613,7 @@ _reevaluate_group_pcr_offset (MpegTSPCR * pcrtable, PCROffsetGroup * group)
* We will use raw (non-corrected/non-absolute) PCR values in a first time
* to detect wraparound/resets/gaps...
*
- * We will use the corrected/asolute PCR values to calculate
+ * We will use the corrected/absolute PCR values to calculate
* bitrate and estimate the target group pcr_offset.
* */
diff --git a/gst/mpegtsdemux/tsdemux.c b/gst/mpegtsdemux/tsdemux.c
index 8bc973690..f19925765 100644
--- a/gst/mpegtsdemux/tsdemux.c
+++ b/gst/mpegtsdemux/tsdemux.c
@@ -1222,7 +1222,7 @@ create_pad_for_stream (MpegTSBase * base, MpegTSBaseStream * bstream,
case ST_PS_VIDEO_MPEG2_DCII:
/* FIXME : Use DCII registration code (ETV1 ?) to handle that special
* Stream type (ST_PS_VIDEO_MPEG2_DCII) */
- /* FIXME : Use video decriptor (0x1) to refine caps with:
+ /* FIXME : Use video descriptor (0x1) to refine caps with:
* * frame_rate
* * profile_and_level
*/
diff --git a/gst/mpegtsmux/gstmpegtsmux.c b/gst/mpegtsmux/gstmpegtsmux.c
index 29f70bf5d..a2ca00ad7 100644
--- a/gst/mpegtsmux/gstmpegtsmux.c
+++ b/gst/mpegtsmux/gstmpegtsmux.c
@@ -336,7 +336,7 @@ gst_mpeg_ts_mux_set_property (GObject * object, guint prop_id,
switch (prop_id) {
case PROP_M2TS_MODE:
- /* set incase if the output stream need to be of 192 bytes */
+ /* set in case if the output stream need to be of 192 bytes */
mux->m2ts_mode = g_value_get_boolean (value);
gst_base_ts_mux_set_packet_size (GST_BASE_TS_MUX (mux),
mux->m2ts_mode ? M2TS_PACKET_LENGTH :
diff --git a/gst/mpegtsmux/tsmux/tsmux.c b/gst/mpegtsmux/tsmux/tsmux.c
index 52dd55917..139c9467e 100644
--- a/gst/mpegtsmux/tsmux/tsmux.c
+++ b/gst/mpegtsmux/tsmux/tsmux.c
@@ -413,7 +413,7 @@ tsmux_program_compare (TsMuxProgram * program, gint * needle)
* tsmux_program_new:
* @mux: a #TsMux
*
- * Create a new program in the mising session @mux.
+ * Create a new program in the missing session @mux.
*
* Returns: a new #TsMuxProgram or %NULL when the maximum number of programs has
* been reached.
@@ -697,7 +697,7 @@ tsmux_create_stream (TsMux * mux, guint stream_type, guint16 pid,
* @mux: a #TsMux
* @pid: the PID to find.
*
- * Find the stream associated wih PID.
+ * Find the stream associated with PID.
*
* Returns: a #TsMuxStream with @pid or NULL when the stream was not found.
*/
diff --git a/gst/mpegtsmux/tsmux/tsmuxstream.c b/gst/mpegtsmux/tsmux/tsmuxstream.c
index 2e5fa2d68..5eb6abff4 100644
--- a/gst/mpegtsmux/tsmux/tsmuxstream.c
+++ b/gst/mpegtsmux/tsmux/tsmuxstream.c
@@ -1024,7 +1024,7 @@ tsmux_stream_default_get_es_descrs (TsMuxStream * stream,
g_ptr_array_add (pmt_stream->descriptors, descriptor);
break;
case TSMUX_ST_PS_DVB_SUBPICTURE:
- /* falltrough ...
+ /* fallthrough ...
* that should never happen anyway as
* dvb subtitles are private data */
case TSMUX_ST_PRIVATE_DATA:
diff --git a/gst/mxf/mxfdms1.c b/gst/mxf/mxfdms1.c
index d735e4d60..bb5234e8f 100644
--- a/gst/mxf/mxfdms1.c
+++ b/gst/mxf/mxfdms1.c
@@ -4684,7 +4684,7 @@ mxf_dms1_rights_handle_tag (MXFMetadataBase * metadata, MXFPrimerPack * primer,
GST_DEBUG (" rights holder = %s", GST_STR_NULL (self->rights_holder));
} else if (memcmp (tag_ul, &rights_managment_authority_ul, 16) == 0) {
self->rights_managment_authority = mxf_utf16_to_utf8 (tag_data, tag_size);
- GST_DEBUG (" rights managment authority = %s",
+ GST_DEBUG (" rights management authority = %s",
GST_STR_NULL (self->rights_managment_authority));
} else if (memcmp (tag_ul, &region_or_area_of_ip_license_ul, 16) == 0) {
self->region_or_area_of_ip_license = mxf_utf16_to_utf8 (tag_data, tag_size);
diff --git a/gst/netsim/gstnetsim.c b/gst/netsim/gstnetsim.c
index 0c27a67f5..39368ed15 100644
--- a/gst/netsim/gstnetsim.c
+++ b/gst/netsim/gstnetsim.c
@@ -68,7 +68,7 @@ enum
PROP_ALLOW_REORDERING,
};
-/* these numbers are nothing but wild guesses and dont reflect any reality */
+/* these numbers are nothing but wild guesses and don't reflect any reality */
#define DEFAULT_MIN_DELAY 200
#define DEFAULT_MAX_DELAY 400
#define DEFAULT_DELAY_DISTRIBUTION DISTRIBUTION_UNIFORM
diff --git a/gst/pcapparse/gstirtspparse.c b/gst/pcapparse/gstirtspparse.c
index 4d64e36f6..e9ab037df 100644
--- a/gst/pcapparse/gstirtspparse.c
+++ b/gst/pcapparse/gstirtspparse.c
@@ -194,7 +194,7 @@ start:
switch (IRTSPParse->state) {
case IRTSP_SEARCH_FRAME:
- /* Use the first occurence of 0x24 as a start of interleaved frames.
+ /* Use the first occurrence of 0x24 as a start of interleaved frames.
* This 'trick' allows us to parse a dump that doesn't contain RTSP
* handshake. It's up to user to provide the data where the first 0x24
* is an RTSP frame */
diff --git a/gst/pnm/gstpnmdec.c b/gst/pnm/gstpnmdec.c
index cf6904e01..b11a7310b 100644
--- a/gst/pnm/gstpnmdec.c
+++ b/gst/pnm/gstpnmdec.c
@@ -149,7 +149,7 @@ gst_pnmdec_negotiate (GstVideoDecoder * decoder)
const gchar *fmtstr;
pnmdec->size = pnmdec->mngr.info.width * pnmdec->mngr.info.height * 2;
- /* perform some basic negotiation to resolve which endianess,
+ /* perform some basic negotiation to resolve which endianness,
* if any, is supported by the component downstream. Query
* the peer caps, intersecting with our preferred caps
*/
diff --git a/gst/removesilence/gstremovesilence.c b/gst/removesilence/gstremovesilence.c
index a932f6111..5529f6a9e 100644
--- a/gst/removesilence/gstremovesilence.c
+++ b/gst/removesilence/gstremovesilence.c
@@ -137,7 +137,7 @@ gst_remove_silence_class_init (GstRemoveSilenceClass * klass)
g_object_class_install_property (gobject_class, PROP_REMOVE,
g_param_spec_boolean ("remove", "Remove",
- "Set to true to remove silence from the stream, false otherwhise",
+ "Set to true to remove silence from the stream, false otherwise",
FALSE, G_PARAM_READWRITE));
g_object_class_install_property (gobject_class, PROP_HYSTERESIS,
@@ -206,7 +206,7 @@ gst_remove_silence_reset (GstRemoveSilence * filter)
/* initialize the new element
* instantiate pads and add them to element
- * set pad calback functions
+ * set pad callback functions
* initialize instance structure
*/
static void
@@ -416,7 +416,7 @@ gst_remove_silence_transform_ip (GstBaseTransform * trans, GstBuffer * inbuf)
inbuf = gst_buffer_make_writable (inbuf);
GST_BUFFER_PTS (inbuf) -= filter->ts_offset;
} else {
- GST_WARNING ("Invalid buffer pts, update not possibile");
+ GST_WARNING ("Invalid buffer pts, update not possible");
}
}
diff --git a/gst/rist/gstristrtxsend.c b/gst/rist/gstristrtxsend.c
index 927fb1cf0..1846c3840 100644
--- a/gst/rist/gstristrtxsend.c
+++ b/gst/rist/gstristrtxsend.c
@@ -329,7 +329,7 @@ gst_rist_rtx_send_get_ssrc_data (GstRistRtxSend * rtx, guint32 ssrc)
data = g_hash_table_lookup (rtx->ssrc_data, GUINT_TO_POINTER (ssrc));
if (!data) {
- /* See 5.3.2 Retransmitted Packets, orignal packet have SSRC LSB set to
+ /* See 5.3.2 Retransmitted Packets, original packet have SSRC LSB set to
* 0, while RTX packet have LSB set to 1 */
rtx_ssrc = ssrc + 1;
data = ssrc_rtx_data_new (rtx_ssrc);
diff --git a/gst/rist/gstristsink.c b/gst/rist/gstristsink.c
index 08e165712..46d85a0bb 100644
--- a/gst/rist/gstristsink.c
+++ b/gst/rist/gstristsink.c
@@ -1263,7 +1263,7 @@ gst_rist_sink_class_init (GstRistSinkClass * klass)
g_object_class_install_property (object_class, PROP_BONDING_ADDRESSES,
g_param_spec_string ("bonding-addresses", "Bonding Addresses",
- "Comma (,) seperated list of <address>:<port> to send to. ", NULL,
+ "Comma (,) separated list of <address>:<port> to send to. ", NULL,
G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
g_object_class_install_property (object_class, PROP_BONDING_METHOD,
diff --git a/gst/rist/gstroundrobin.c b/gst/rist/gstroundrobin.c
index 55e4152a3..2ff8ff306 100644
--- a/gst/rist/gstroundrobin.c
+++ b/gst/rist/gstroundrobin.c
@@ -26,7 +26,7 @@
* buffers over multiple src pads. This is the opposite of tee
* element, which duplicates buffers over all pads. This element
* can be used to distrute load across multiple branches when the buffer
- * can be processed indepently.
+ * can be processed independently.
*/
#include "gstroundrobin.h"
diff --git a/gst/rtp/gstrtpsrc.c b/gst/rtp/gstrtpsrc.c
index 387c69157..800b67df9 100644
--- a/gst/rtp/gstrtpsrc.c
+++ b/gst/rtp/gstrtpsrc.c
@@ -450,7 +450,7 @@ gst_rtp_src_rtpbin_on_ssrc_collision_cb (GstElement * rtpbin, guint session_id,
GstRtpSrc *self = GST_RTP_SRC (data);
GST_INFO_OBJECT (self,
- "Dectected an SSRC collision: session-id 0x%x, ssrc 0x%x.", session_id,
+ "Detected an SSRC collision: session-id 0x%x, ssrc 0x%x.", session_id,
ssrc);
}
@@ -460,7 +460,7 @@ gst_rtp_src_rtpbin_on_new_ssrc_cb (GstElement * rtpbin, guint session_id,
{
GstRtpSrc *self = GST_RTP_SRC (data);
- GST_INFO_OBJECT (self, "Dectected a new SSRC: session-id 0x%x, ssrc 0x%x.",
+ GST_INFO_OBJECT (self, "Detected a new SSRC: session-id 0x%x, ssrc 0x%x.",
session_id, ssrc);
}
diff --git a/gst/videoparsers/gsth264parse.c b/gst/videoparsers/gsth264parse.c
index 2e5e49f2d..37facafaf 100644
--- a/gst/videoparsers/gsth264parse.c
+++ b/gst/videoparsers/gsth264parse.c
@@ -401,7 +401,7 @@ gst_h264_parse_negotiate (GstH264Parse * h264parse, gint in_format,
}
}
- /* FIXME We could fail the negotiation immediatly if caps are empty */
+ /* FIXME We could fail the negotiation immediately if caps are empty */
if (caps && !gst_caps_is_empty (caps)) {
/* fixate to avoid ambiguity with lists when parsing */
caps = gst_caps_fixate (caps);
@@ -936,7 +936,7 @@ gst_h264_parse_process_nal (GstH264Parse * h264parse, GstH264NalUnit * nalu)
GST_DEBUG_OBJECT (h264parse, "marking IDR in frame at offset %d",
h264parse->idr_pos);
}
- /* if SEI preceeds (faked) IDR, then we have to insert config there */
+ /* if SEI precedes (faked) IDR, then we have to insert config there */
if (h264parse->sei_pos >= 0 && h264parse->idr_pos > h264parse->sei_pos) {
h264parse->idr_pos = h264parse->sei_pos;
GST_DEBUG_OBJECT (h264parse, "moved IDR mark to SEI position %d",
@@ -2576,7 +2576,7 @@ gst_h264_parse_pre_push_frame (GstBaseParse * parse, GstBaseParseFrame * frame)
h264parse->sent_codec_tag = TRUE;
}
- /* In case of byte-stream, insert au delimeter by default
+ /* In case of byte-stream, insert au delimiter by default
* if it doesn't exist */
if (h264parse->aud_insert && h264parse->format == GST_H264_PARSE_FORMAT_BYTE) {
if (h264parse->align == GST_H264_PARSE_ALIGN_AU) {
@@ -2669,7 +2669,7 @@ gst_h264_parse_pre_push_frame (GstBaseParse * parse, GstBaseParseFrame * frame)
}
}
- /* Fixme: setting passthrough mode casuing multiple issues:
+ /* Fixme: setting passthrough mode causing multiple issues:
* For nal aligned multiresoluton streams, passthrough mode make h264parse
* unable to advertise the new resoultions. Also causing issues while
* parsing MVC streams when it has two layers.
diff --git a/gst/videoparsers/gsth265parse.c b/gst/videoparsers/gsth265parse.c
index 0dddb8615..6277fee4c 100644
--- a/gst/videoparsers/gsth265parse.c
+++ b/gst/videoparsers/gsth265parse.c
@@ -390,7 +390,7 @@ gst_h265_parse_negotiate (GstH265Parse * h265parse, gint in_format,
}
}
- /* FIXME We could fail the negotiation immediatly if caps are empty */
+ /* FIXME We could fail the negotiation immediately if caps are empty */
if (caps && !gst_caps_is_empty (caps)) {
/* fixate to avoid ambiguity with lists when parsing */
caps = gst_caps_fixate (caps);
diff --git a/gst/videoparsers/gstmpeg4videoparse.c b/gst/videoparsers/gstmpeg4videoparse.c
index 298887095..e6628e4ba 100644
--- a/gst/videoparsers/gstmpeg4videoparse.c
+++ b/gst/videoparsers/gstmpeg4videoparse.c
@@ -846,7 +846,7 @@ gst_mpeg4vparse_set_caps (GstBaseParse * parse, GstCaps * caps)
&& (buf = gst_value_get_buffer (value))) {
/* best possible parse attempt,
* src caps are based on sink caps so it will end up in there
- * whether sucessful or not */
+ * whether successful or not */
gst_buffer_map (buf, &map, GST_MAP_READ);
data = map.data;
size = map.size;
diff --git a/gst/videoparsers/gstmpegvideoparse.c b/gst/videoparsers/gstmpegvideoparse.c
index 3eb759d84..ed085ce7b 100644
--- a/gst/videoparsers/gstmpegvideoparse.c
+++ b/gst/videoparsers/gstmpegvideoparse.c
@@ -137,7 +137,7 @@ gst_mpegv_parse_class_init (GstMpegvParseClass * klass)
g_object_class_install_property (gobject_class, PROP_DROP,
g_param_spec_boolean ("drop", "drop",
- "Drop data untill valid configuration data is received either "
+ "Drop data until valid configuration data is received either "
"in the stream or through caps", DEFAULT_PROP_DROP,
G_PARAM_CONSTRUCT | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
@@ -1069,7 +1069,7 @@ gst_mpegv_parse_set_caps (GstBaseParse * parse, GstCaps * caps)
gst_buffer_map (buf, &map, GST_MAP_READ);
/* best possible parse attempt,
* src caps are based on sink caps so it will end up in there
- * whether sucessful or not */
+ * whether successful or not */
mpvparse->seq_offset = 4;
gst_mpegv_parse_process_config (mpvparse, &map, gst_buffer_get_size (buf));
gst_buffer_unmap (buf, &map);
diff --git a/gst/videoparsers/h263parse.c b/gst/videoparsers/h263parse.c
index 5ed99f712..dd8f1a07f 100644
--- a/gst/videoparsers/h263parse.c
+++ b/gst/videoparsers/h263parse.c
@@ -465,7 +465,7 @@ gst_h263_parse_get_params (H263Params * params, GstBuffer * buffer,
/* FIXME: Annex P (Reference Picture Resampling) can be signaled implicitly
* as well as in the header. Should we set the field to false in caps if it
- * is not specfied by the header? */
+ * is not specified by the header? */
/* FIXME: Annex U (Enhanced Reference Picture Selection) poses a problem - we
* have no means of specifying what sub-modes, if any, are used. */
diff --git a/gst/vmnc/vmncdec.c b/gst/vmnc/vmncdec.c
index cbbaeb6b4..40eb20cbb 100644
--- a/gst/vmnc/vmncdec.c
+++ b/gst/vmnc/vmncdec.c
@@ -235,12 +235,12 @@ vmnc_handle_wmvi_rectangle (GstVMncDec * dec, struct RfbRectangle *rect,
format = gst_video_format_from_masks (dec->format.depth, bpp, endianness,
redmask, greenmask, bluemask, 0);
- GST_DEBUG_OBJECT (dec, "From depth: %d bpp: %u endianess: %s redmask: %X "
+ GST_DEBUG_OBJECT (dec, "From depth: %d bpp: %u endianness: %s redmask: %X "
"greenmask: %X bluemask: %X got format %s",
dec->format.depth, bpp, endianness == G_BIG_ENDIAN ? "BE" : "LE",
GUINT32_FROM_BE (redmask), GUINT32_FROM_BE (greenmask),
GUINT32_FROM_BE (bluemask),
- format == GST_VIDEO_FORMAT_UNKNOWN ? "UNKOWN" :
+ format == GST_VIDEO_FORMAT_UNKNOWN ? "UNKNOWN" :
gst_video_format_to_string (format));
if (format == GST_VIDEO_FORMAT_UNKNOWN) {
diff --git a/gst/librfb/rfbdecoder.c b/gst/librfb/rfbdecoder.c
index fa763313a..9d5136b81 100644
--- a/gst/librfb/rfbdecoder.c
+++ b/gst/librfb/rfbdecoder.c
@@ -155,7 +155,7 @@ rfb_decoder_disconnect (RfbDecoder * decoder)
*
* Initializes the connection with the rfb server
*
* Returns: TRUE if initialization was succesfull, FALSE on fail.
*/
gboolean
rfb_decoder_iterate (RfbDecoder * decoder)
@@ -564,7 +564,7 @@ rfb_decoder_state_security_result (RfbDecoder * decoder)
return FALSE;
}
- GST_DEBUG ("Security handshaking succesful");
+ GST_DEBUG ("Security handshake successful");
decoder->state = rfb_decoder_state_send_client_initialisation;
return TRUE;
@@ -598,7 +598,7 @@ rfb_decoder_message_set_encodings (GSList * encodings_list)
*
* Sends the encoding types that the client can decode to the server
*
* Returns: TRUE if initialization was succesfull, FALSE on fail.
*/
static gboolean
rfb_decoder_state_set_encodings (RfbDecoder * decoder)
@@ -807,7 +807,7 @@ rfb_decoder_state_framebuffer_update_rectangle (RfbDecoder * decoder)
h = RFB_GET_UINT16 (decoder->data + 6);
encoding = RFB_GET_UINT32 (decoder->data + 8);
- GST_DEBUG ("update recieved");
+ GST_DEBUG ("update received");
GST_DEBUG ("x:%d y:%d", x, y);
GST_DEBUG ("w:%d h:%d", w, h);
GST_DEBUG ("encoding: %d", encoding);
@@ -155,7 +155,7 @@ rfb_decoder_disconnect (RfbDecoder * decoder)
* Initializes the connection with the rfb server
*
- * Returns: TRUE if initialization was succesfull, FALSE on fail.
+ * Returns: TRUE if initialization was successful, FALSE on fail.
*/
gboolean
@@ -598,7 +598,7 @@ rfb_decoder_message_set_encodings (GSList * encodings_list)
* Sends the encoding types that the client can decode to the server
*
- * Returns: TRUE if initialization was succesfull, FALSE on fail.
+ * Returns: TRUE if initialization was successful, FALSE on fail.
*/
static gboolean